@@ -1,26 +1,32 @@
 """Augmentations."""
 #  pylint: disable=invalid-name
+import itertools
+
+from astroid import InferenceError
+from astroid.objects import Super
+from astroid.nodes import ClassDef, ImportFrom, Attribute
+from astroid.scoped_nodes import Class as ScopedClass, Module
+
 from pylint.checkers.base import DocStringChecker, NameChecker
 from pylint.checkers.design_analysis import MisdesignChecker
 from pylint.checkers.classes import ClassChecker
 from pylint.checkers.newstyle import NewStyleConflictChecker
 from pylint.checkers.variables import VariablesChecker
-from astroid import InferenceError
-from pylint_django.compat import ClassDef, ImportFrom, Attribute, django_version
-from astroid.objects import Super
-from astroid.scoped_nodes import Class as ScopedClass, Module
 from pylint.__pkginfo__ import numversion as PYLINT_VERSION
 from pylint.checkers.typecheck import TypeChecker
 from pylint.checkers.variables import ScopeConsumer
-from pylint_django.utils import node_is_subclass, PY3
-from pylint_django.compat import inferred
+
 from pylint_plugin_utils import augment_visit, suppress_message
 
+from django import VERSION as django_version
 from django.views.generic.base import View, RedirectView, ContextMixin
 from django.views.generic.dates import DateMixin, DayMixin, MonthMixin, WeekMixin, YearMixin
 from django.views.generic.detail import SingleObjectMixin, SingleObjectTemplateResponseMixin, TemplateResponseMixin
 from django.views.generic.edit import DeletionMixin, FormMixin, ModelFormMixin
 from django.views.generic.list import MultipleObjectMixin, MultipleObjectTemplateResponseMixin
+from django.utils import termcolors
+
+from pylint_django.utils import node_is_subclass, PY3
 
 
 # Note: it would have been nice to import the Manager object from Django and
@@ -255,6 +261,9 @@ ONETOONE_FIELD_ATTRS = {
 }
 
 
+STYLE_ATTRS = set(itertools.chain.from_iterable(termcolors.PALETTES.values()))
+
+
 VIEW_ATTRS = {
     (
         (
@@ -339,7 +348,7 @@ def foreign_key_sets(chain, node):
         children = list(node.get_children())
         for child in children:
             try:
-                inferred_cls = inferred(child)()
+                inferred_cls = child.inferred()
             except InferenceError:
                 pass
             else:
@@ -418,6 +427,25 @@ def is_model_factory_meta_subclass(node):
     return node_is_subclass(node.parent, *parents)
 
 
+def is_model_factory(node):
+    """Checks that node is derivative of SubFactory class."""
+    try:
+        parent_classes = node.expr.inferred()
+    except:  # noqa: E722, pylint: disable=bare-except
+        return False
+
+    parents = ('factory.declarations.SubFactory',)
+
+    for parent_class in parent_classes:
+        try:
+            if parent_class.qname() in parents:
+                return True
+        except AttributeError:
+            continue
+
+    return False
+
+
 def is_model_mpttmeta_subclass(node):
     """Checks that node is derivative of MPTTMeta class."""
     if node.name != 'MPTTMeta' or not isinstance(node.parent, ClassDef):
@@ -440,9 +468,9 @@ def _attribute_is_magic(node, attrs, parents):
         return False
 
     try:
-        for cls in inferred(node.last_child())():
+        for cls in node.last_child().inferred():
             if isinstance(cls, Super):
-                cls = cls._self_class
+                cls = cls._self_class  # pylint: disable=protected-access
             if node_is_subclass(cls, *parents) or cls.qname() in parents:
                 return True
     except InferenceError:
@@ -450,6 +478,11 @@ def _attribute_is_magic(node, attrs, parents):
     return False
 
 
+def is_style_attribute(node):
+    parents = ('django.core.management.color.Style', )
+    return _attribute_is_magic(node, STYLE_ATTRS, parents)
+
+
 def is_manager_attribute(node):
     """Checks that node is attribute of Manager or QuerySet class."""
     parents = ('django.db.models.manager.Manager',
@@ -588,21 +621,28 @@ def is_model_view_subclass_unused_argument(node):
     if not is_model_view_subclass_method_shouldnt_be_function(node):
         return False
 
-    return 'request' in node.argnames()
+    return is_argument_named_request(node)
+
+
+def is_argument_named_request(node):
+    """
+    If an unused-argument is named 'request' ignore that!
+    """
+    return 'request'in node.argnames()
 
 
 def is_model_field_display_method(node):
     """Accept model's fields with get_*_display names."""
     if not node.attrname.endswith('_display'):
-        return
+        return False
     if not node.attrname.startswith('get_'):
-        return
+        return False
 
     if node.last_child():
         # TODO: could validate the names of the fields on the model rather than
         # blindly accepting get_*_display
         try:
-            for cls in inferred(node.last_child())():
+            for cls in node.last_child().inferred():
                 if node_is_subclass(cls, 'django.db.models.base.Model', '.Model'):
                     return True
         except InferenceError:
@@ -658,8 +698,8 @@ def is_urls_module_valid_constant(node):
 def allow_meta_protected_access(node):
     if django_version >= (1, 8):
         return node.attrname == '_meta'
-    else:
-        return False
+
+    return False
 
 
 def is_class(class_name):
@@ -673,6 +713,12 @@ def wrap(orig_method, with_method):
     return wrap_func
 
 
+def is_wsgi_application(node):
+    frame = node.frame()
+    return node.name == 'application' and isinstance(frame, Module) and \
+        (frame.name == 'wsgi' or frame.path.endswith('wsgi.py') or frame.file.endswith('wsgi.py'))
+
+
 # The names of some visit functions changed in this commit:
 # https://bitbucket.org/logilab/pylint/commits/c94ee95abaa5737f13b91626fe321150c0ddd140
 
@@ -704,26 +750,27 @@ def apply_augmentations(linter):
     """Apply augmentation and suppression rules."""
     augment_visit(linter, _visit_attribute(TypeChecker), foreign_key_sets)
     augment_visit(linter, _visit_attribute(TypeChecker), foreign_key_ids)
-    suppress_message(linter, _visit_attribute(TypeChecker), 'E1101', is_model_field_display_method)
+    suppress_message(linter, _visit_attribute(TypeChecker), 'no-member', is_model_field_display_method)
+    suppress_message(linter, _visit_attribute(TypeChecker), 'no-member', is_style_attribute)
 
     # supress errors when accessing magical class attributes
-    suppress_message(linter, _visit_attribute(TypeChecker), 'E1101', is_manager_attribute)
-    suppress_message(linter, _visit_attribute(TypeChecker), 'E1101', is_admin_attribute)
-    suppress_message(linter, _visit_attribute(TypeChecker), 'E1101', is_model_attribute)
-    suppress_message(linter, _visit_attribute(TypeChecker), 'E1101', is_field_attribute)
-    suppress_message(linter, _visit_attribute(TypeChecker), 'E1101', is_charfield_attribute)
-    suppress_message(linter, _visit_attribute(TypeChecker), 'E1101', is_datefield_attribute)
-    suppress_message(linter, _visit_attribute(TypeChecker), 'E1101', is_decimalfield_attribute)
-    suppress_message(linter, _visit_attribute(TypeChecker), 'E1101', is_filefield_attribute)
-    suppress_message(linter, _visit_attribute(TypeChecker), 'E1101', is_imagefield_attribute)
-    suppress_message(linter, _visit_attribute(TypeChecker), 'E1101', is_ipfield_attribute)
-    suppress_message(linter, _visit_attribute(TypeChecker), 'E1101', is_slugfield_attribute)
-    suppress_message(linter, _visit_attribute(TypeChecker), 'E1101', is_foreignkeyfield_attribute)
-    suppress_message(linter, _visit_attribute(TypeChecker), 'E1101', is_manytomanyfield_attribute)
-    suppress_message(linter, _visit_attribute(TypeChecker), 'E1101', is_onetoonefield_attribute)
+    suppress_message(linter, _visit_attribute(TypeChecker), 'no-member', is_manager_attribute)
+    suppress_message(linter, _visit_attribute(TypeChecker), 'no-member', is_admin_attribute)
+    suppress_message(linter, _visit_attribute(TypeChecker), 'no-member', is_model_attribute)
+    suppress_message(linter, _visit_attribute(TypeChecker), 'no-member', is_field_attribute)
+    suppress_message(linter, _visit_attribute(TypeChecker), 'no-member', is_charfield_attribute)
+    suppress_message(linter, _visit_attribute(TypeChecker), 'no-member', is_datefield_attribute)
+    suppress_message(linter, _visit_attribute(TypeChecker), 'no-member', is_decimalfield_attribute)
+    suppress_message(linter, _visit_attribute(TypeChecker), 'no-member', is_filefield_attribute)
+    suppress_message(linter, _visit_attribute(TypeChecker), 'no-member', is_imagefield_attribute)
+    suppress_message(linter, _visit_attribute(TypeChecker), 'no-member', is_ipfield_attribute)
+    suppress_message(linter, _visit_attribute(TypeChecker), 'no-member', is_slugfield_attribute)
+    suppress_message(linter, _visit_attribute(TypeChecker), 'no-member', is_foreignkeyfield_attribute)
+    suppress_message(linter, _visit_attribute(TypeChecker), 'no-member', is_manytomanyfield_attribute)
+    suppress_message(linter, _visit_attribute(TypeChecker), 'no-member', is_onetoonefield_attribute)
 
     for parents, attrs in VIEW_ATTRS:
-        suppress_message(linter, _visit_attribute(TypeChecker), 'E1101', generic_is_view_attribute(parents, attrs))
+        suppress_message(linter, _visit_attribute(TypeChecker), 'no-member', generic_is_view_attribute(parents, attrs))
 
     # formviews have too many ancestors, there's nothing the user of the library can do about that
     suppress_message(linter, _visit_class(MisdesignChecker), 'too-many-ancestors',
@@ -769,7 +816,9 @@ def apply_augmentations(linter):
     # Method could be a function (get, post)
     suppress_message(linter, _leave_function(ClassChecker), 'R0201', is_model_view_subclass_method_shouldnt_be_function)
     # Unused argument 'request' (get, post)
-    suppress_message(linter, _leave_function(VariablesChecker), 'W0613', is_model_view_subclass_unused_argument)
+    suppress_message(linter, _leave_function(VariablesChecker), 'unused-argument',
+                     is_model_view_subclass_unused_argument)
+    suppress_message(linter, _leave_function(VariablesChecker), 'unused-argument', is_argument_named_request)
 
     # django-mptt
     suppress_message(linter, _visit_class(DocStringChecker), 'missing-docstring', is_model_mpttmeta_subclass)
@@ -782,6 +831,7 @@ def apply_augmentations(linter):
     suppress_message(linter, _visit_class(NewStyleConflictChecker), 'old-style-class', is_model_factory_meta_subclass)
     suppress_message(linter, _visit_class(ClassChecker), 'W0232', is_model_factory_meta_subclass)
     suppress_message(linter, _leave_class(MisdesignChecker), 'too-few-public-methods', is_model_factory_meta_subclass)
+    suppress_message(linter, _visit_attribute(TypeChecker), 'no-member', is_model_factory)
 
     # ForeignKey and OneToOneField
     # Must update this in a thread safe way to support the parallel option on pylint (-j)
@@ -792,3 +842,6 @@ def apply_augmentations(linter):
         VariablesChecker.leave_module = wrap(current_leave_module, ignore_import_warnings_for_related_fields)
         # VariablesChecker.leave_module is now wrapped
     # else VariablesChecker.leave_module is already wrapped
+
+    # wsgi.py
+    suppress_message(linter, _visit_assignname(NameChecker), 'invalid-name', is_wsgi_application)
