@@ -1,11 +1,13 @@
 """Models."""
 from astroid import Const
-from pylint_django.compat import ClassDef, FunctionDef, inferred, AssignName
 from astroid.nodes import Assign
+from astroid.nodes import ClassDef, FunctionDef, AssignName
+
 from pylint.interfaces import IAstroidChecker
 from pylint.checkers.utils import check_messages
 from pylint.checkers import BaseChecker
 from pylint.__pkginfo__ import numversion as PYLINT_VERSION
+
 from pylint_django.__pkginfo__ import BASE_ID
 from pylint_django.utils import node_is_subclass, PY3
 
@@ -46,6 +48,27 @@ def _is_meta_with_abstract(node):
     return False
 
 
+def _has_python_2_unicode_compatible_decorator(node):
+    if node.decorators is None:
+        return False
+
+    for decorator in node.decorators.nodes:
+        if getattr(decorator, 'name', None) == 'python_2_unicode_compatible':
+            return True
+
+    return False
+
+
+def _is_unicode_or_str_in_python_2_compatibility(method):
+    if method.name == '__unicode__':
+        return True
+
+    if method.name == '__str__' and _has_python_2_unicode_compatible_decorator(method.parent):
+        return True
+
+    return False
+
+
 class ModelChecker(BaseChecker):
     """Django model checker."""
     __implements__ = IAstroidChecker
@@ -53,7 +76,7 @@ class ModelChecker(BaseChecker):
     name = 'django-model-checker'
     msgs = MESSAGES
 
-    # XXX: there's a bug in pylint's backwards compatability logic after changing
+    # NOTE: there's a bug in pylint's backwards compatability logic after changing
     # visit method names from visit_class to visit_classdef, see
     # https://bitbucket.org/logilab/pylint/issues/711/new-node-visit-methods-not-backwards
     if PYLINT_VERSION < (1, 5):
@@ -86,7 +109,7 @@ class ModelChecker(BaseChecker):
                     continue
 
                 grandchild = grandchildren[1]
-                assigned = inferred(grandchild)()[0]
+                assigned = grandchild.inferred()[0]
 
                 if assigned.callable():
                     return
@@ -100,12 +123,10 @@ class ModelChecker(BaseChecker):
                 return
 
         # if we get here, then we have no __unicode__ method directly on the class itself
-        if PY3:
-            return
 
         # a different warning is emitted if a parent declares __unicode__
         for method in node.methods():
-            if method.name == '__unicode__':
+            if method.parent != node and _is_unicode_or_str_in_python_2_compatibility(method):
                 # this happens if a parent declares the unicode method but
                 # this node does not
                 self.add_message('W%s03' % BASE_ID, args=node.name, node=node)
@@ -113,9 +134,10 @@ class ModelChecker(BaseChecker):
 
         # if the Django compatibility decorator is used then we don't emit a warning
         # see https://github.com/PyCQA/pylint-django/issues/10
-        if node.decorators is not None:
-            for decorator in node.decorators.nodes:
-                if getattr(decorator, 'name', None) == 'python_2_unicode_compatible':
-                    return
+        if _has_python_2_unicode_compatible_decorator(node):
+            return
+
+        if PY3:
+            return
 
         self.add_message('W%s01' % BASE_ID, args=node.name, node=node)
