@@ -1,11 +1,13 @@
 """Transforms."""
 import os
 import re
-from pylint_django.transforms import foreignkey, fields
+
 from astroid import MANAGER
 from astroid.builder import AstroidBuilder
 from astroid import nodes
 
+from pylint_django.transforms import foreignkey, fields
+
 
 foreignkey.add_transform(MANAGER)
 fields.add_transforms(MANAGER)
@@ -44,3 +46,9 @@ _add_transform('django.db.models',
                'Manager')
 _add_transform('django.utils.translation', 'ugettext_lazy')
 _add_transform('mongoengine', 'Document')
+_add_transform('model_utils.managers',
+               'InheritanceManager',
+               'QueryManager',
+               'SoftDeletableManager')
+# register transform for FileField/ImageField, see #60
+_add_transform('django.db.models.fields.files', 'FileField')
