@@ -1,5 +1,7 @@
-from astroid import MANAGER, scoped_nodes, nodes, inference_tip
 import sys
+
+from astroid import MANAGER, scoped_nodes, nodes, inference_tip
+
 from pylint_django import utils
 
 
@@ -26,7 +28,7 @@ def is_model_or_form_field(cls):
     return is_model_field(cls) or is_form_field(cls)
 
 
-def apply_type_shim(cls, context=None):  # noqa
+def apply_type_shim(cls, _context=None):  # noqa
 
     if cls.name in _STR_FIELDS:
         base_nodes = scoped_nodes.builtin_lookup('str')
